==> senaite.jsonapi-1.1.0.zip: senaite.jsonapi-1.1.0/src/senaite/jsonapi/config.py <==
# -*- coding: utf-8 -*-


# The location mentioned here take precendence over any given container path
# defined in the request.
CONTAINER_PATHS_FOR_PORTAL_TYPES = {
    # 'ARImport': '',
    # 'ARPriorities': '',
    'ARPriority': 'bika_setup/bika_arpriorities',
    # 'ARReport': '',
    'ARTemplate': 'bika_setup/bika_artemplates',
    # 'ARTemplates': '',
    # 'ATBooleanCriterion': '',
    # 'ATCurrentAuthorCriterion': '',
    # 'ATDateCriteria': '',
    # 'ATDateRangeCriterion': '',
    # 'ATListCriterion': '',
    # 'ATPathCriterion': '',
    # 'ATPortalTypeCriterion': '',
    # 'ATReferenceCriterion': '',
    # 'ATRelativePathCriterion': '',
    # 'ATSelectionCriterion': '',
    # 'ATSimpleIntCriterion': '',
    # 'ATSimpleStringCriterion': '',
    # 'ATSortCriterion': '',
    # 'Analysis': '',
    # 'AnalysisCategories': '',
    'AnalysisCategory': 'bika_setup/bika_analysiscategories',
    'AnalysisProfile': 'bika_setup/bika_analysisprofiles',
    # 'AnalysisProfiles': '',
    # 'AnalysisRequest': '',
    # 'AnalysisRequestsFolder': '',
    'AnalysisService': 'bika_setup/bika_analysisservices',
    # 'AnalysisServices': '',
    'AnalysisSpec': 'bika_setup/bika_analysisspecs',
    # 'AnalysisSpecs': '',
    # 'Attachment': '',
    'AttachmentType': 'bika_setup/bika_attachmenttypes',
    # 'AttachmentTypes': '',
    # 'Batch': '',
    # 'BatchFolder': '',
    'BatchLabel': 'bika_setup/bika_batchlabels',
    # 'BatchLabels': '',
    # 'BikaSetup': '',
    'Calculation': 'bika_setup/bika_calculations',
    # 'Calculations': '',
    'Client': 'clients',
    # 'ClientFolder': '',
    # 'Collection': '',
    # 'Contact': '',
    'Container': 'bika_setup/bika_containers',
    # 'ContainerType': '',
    # 'ContainerTypes': '',
    # 'Containers': '',
    'Department': 'bika_setup/bika_departments',
    # 'Departments': '',
    # 'Discussion Item': '',
    # 'Document': '',
    # 'DuplicateAnalysis': '',
    # 'Event': '',
    # 'File': '',
    # 'Folder': '',
    'IdentifierType': 'bika_setup/bika_identifiertypes',
    # 'IdentifierTypes': '',
    # 'Image': '',
    'Instrument': 'bika_setup/bika_instruments',
    # 'InstrumentCalibration': '',
    # 'InstrumentCertification': '',
    'InstrumentLocation': 'bika_setup/bika_instrumentlocations',
    # 'InstrumentLocations': '',
    # 'InstrumentMaintenanceTask': '',
    # 'InstrumentScheduledTask': '',
    'InstrumentType': 'bika_setup/bika_instrumenttypes',
    # 'InstrumentTypes': '',
    # 'InstrumentValidation': '',
    # 'Instruments': '',
    # 'Invoice': '',
    # 'InvoiceBatch': '',
    # 'InvoiceFolder': '',
    'LabContact': 'bika_setup/bika_labcontacts',
    # 'LabContacts': '',
    'LabProduct': 'bika_setup/bika_labproducts',
    # 'LabProducts': '',
    # 'Laboratory': '',
    # 'Link': '',
    'Manufacturer': 'bika_setup/bika_manufacturers',
    # 'Manufacturers': '',
    'Method': 'methods',
    # 'Methods': '',
    # 'Multifile': '',
    # 'News Item': '',
    # 'Plone Site': '',
    'Preservation': 'bika_setup/bika_preservations',
    # 'Preservations': '',
    # 'Pricelist': '',
    # 'PricelistFolder': '',
    # 'ReferenceAnalysis': '',
    'ReferenceDefinition': 'bika_setup/bika_referencedefinitions',
    # 'ReferenceDefinitions': '',
    # 'ReferenceSample': '',
    # 'ReferenceSamplesFolder': '',
    # 'RejectAnalysis': '',
    # 'Report': '',
    # 'ReportFolder': '',
    'SRTemplate': 'bika_setup/bika_srtemplates',
    # 'SRTemplates': '',
    # 'Sample': '',
    'SampleCondition': 'bika_setup/bika_sampleconditions',
    # 'SampleConditions': '',
    # 'SampleMatrices': '',
    'SampleMatrix': 'bika_setup/bika_samplematrices',
    # 'SamplePartition': '',
    'SamplePoint': 'bika_setup/bika_samplepoints',
    # 'SamplePoints': '',
    'SampleType': 'bika_setup/bika_sampletypes',
    # 'SampleTypes': '',
    # 'SamplesFolder': '',
    'SamplingDeviation': 'bika_setup/bika_samplingdeviations',
    # 'SamplingDeviations': '',
    'SamplingRound': 'bika_setup/bika_samplingrounds',
    # 'SamplingRounds': '',
    'StorageLocation': 'bika_setup/bika_storagelocations',
    # 'StorageLocations': '',
    'SubGroup': 'bika_setup/bika_subgroups',
    # 'SubGroups': '',
    'Supplier': 'bika_setup/bika_suppliers',
    # 'SupplierContact': '',
    # 'Suppliers': '',
    # 'SupplyOrder': '',
    # 'SupplyOrderFolder': '',
    # 'TempFolder': '',
    # 'Topic': '',
    # 'Worksheet': '',
    # 'WorksheetFolder': '',
    'WorksheetTemplate': 'bika_setup/bika_worksheettemplates',
    # 'WorksheetTemplates': '',
}

ALLOWED_PORTAL_TYPES_TO_CREATE = [
    # 'ARImport',
    # 'ARPriorities',
    'ARPriority',
    # 'ARReport',
    'ARTemplate',
    # 'ARTemplates',
    # 'ATBooleanCriterion',
    # 'ATCurrentAuthorCriterion',
    # 'ATDateCriteria',
    # 'ATDateRangeCriterion',
    # 'ATListCriterion',
    # 'ATPathCriterion',
    # 'ATPortalTypeCriterion',
    # 'ATReferenceCriterion',
    # 'ATRelativePathCriterion',
    # 'ATSelectionCriterion',
    # 'ATSimpleIntCriterion',
    # 'ATSimpleStringCriterion',
    # 'ATSortCriterion',
    'Analysis',
    # 'AnalysisCategories',
    'AnalysisCategory',
    'AnalysisProfile',
    # 'AnalysisProfiles',
    'AnalysisRequest',
    # 'AnalysisRequestsFolder',
    'AnalysisService',
    # 'AnalysisServices',
    'AnalysisSpec',
    # 'AnalysisSpecs',
    'Attachment',
    'AttachmentType',
    # 'AttachmentTypes',
    'Batch',
    # 'BatchFolder',
    'BatchLabel',
    # 'BatchLabels',
    # 'BikaSetup',
    'Calculation',
    # 'Calculations',
    'Client',
    # 'ClientFolder',
    # 'Collection',
    'Contact',
    'Container',
    'ContainerType',
    # 'ContainerTypes',
    # 'Containers',
    'Department',
    # 'Departments',
    # 'Discussion Item',
    'Document',
    # 'DuplicateAnalysis',
    # 'Event',
    'File',
    # 'Folder',
    'IdentifierType',
    # 'IdentifierTypes',
    'Image',
    'Instrument',
    'InstrumentCalibration',
    # 'InstrumentCertification',
    'InstrumentLocation',
    # 'InstrumentLocations',
    # 'InstrumentMaintenanceTask',
    # 'InstrumentScheduledTask',
    'InstrumentType',
    # 'InstrumentTypes',
    # 'InstrumentValidation',
    # 'Instruments',
    'Invoice',
    'InvoiceBatch',
    # 'InvoiceFolder',
    'LabContact',
    # 'LabContacts',
    'LabProduct',
    # 'LabProducts',
    # 'Laboratory',
    # 'Link',
    'Manufacturer',
    # 'Manufacturers',
    'Method',
    # 'Methods',
    'Multifile',
    # 'News Item',
    # 'Plone Site',
    'Preservation',
    # 'Preservations',
    'Pricelist',
    # 'PricelistFolder',
    # 'ReferenceAnalysis',
    'ReferenceDefinition',
    # 'ReferenceDefinitions',
    'ReferenceSample',
    # 'ReferenceSamplesFolder',
    'RejectAnalysis',
    'Report',
    # 'ReportFolder',
    'SRTemplate',
    # 'SRTemplates',
    'Sample',
    'SampleCondition',
    # 'SampleConditions',
    # 'SampleMatrices',
    'SampleMatrix',
    # 'SamplePartition',
    'SamplePoint',
    # 'SamplePoints',
    'SampleType',
    # 'SampleTypes',
    # 'SamplesFolder',
    'SamplingDeviation',
    # 'SamplingDeviations',
    'SamplingRound',
    # 'SamplingRounds',
    'StorageLocation',
    # 'StorageLocations',
    'SubGroup',
    # 'SubGroups',
    'Supplier',
    'SupplierContact',
    # 'Suppliers',
    'SupplyOrder',
    # 'SupplyOrderFolder',
    # 'TempFolder',
    # 'Topic',
    'Worksheet',
    # 'WorksheetFolder',
    'WorksheetTemplate',
    # 'WorksheetTemplates',
]

==> senaite.jsonapi-1.2.2.zip: senaite.jsonapi-1.2.2/src/senaite/jsonapi/config.py <==
# -*- coding: utf-8 -*-
#
# This file is part of SENAITE.JSONAPI.
#
# SENAITE.JSONAPI is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright 2017-2020 by it's authors.
# Some rights reserved, see README and LICENSE.

CONTAINER_PATHS_FOR_PORTAL_TYPES = {
    # 'ARImport': '',
    # 'ARPriorities': '',
    # 'ARPriority': 'bika_setup/bika_arpriorities',
    # 'ARReport': '',
    'ARTemplate': 'bika_setup/bika_artemplates',
    # 'ARTemplates': '',
    # 'ATBooleanCriterion': '',
    # 'ATCurrentAuthorCriterion': '',
    # 'ATDateCriteria': '',
    # 'ATDateRangeCriterion': '',
    # 'ATListCriterion': '',
    # 'ATPathCriterion': '',
    # 'ATPortalTypeCriterion': '',
    # 'ATReferenceCriterion': '',
    # 'ATRelativePathCriterion': '',
    # 'ATSelectionCriterion': '',
    # 'ATSimpleIntCriterion': '',
    # 'ATSimpleStringCriterion': '',
    # 'ATSortCriterion': '',
    # 'Analysis': '',
    # 'AnalysisCategories': '',
    'AnalysisCategory': 'bika_setup/bika_analysiscategories',
    'AnalysisProfile': 'bika_setup/bika_analysisprofiles',
    # 'AnalysisProfiles': '',
    # 'AnalysisRequest': '',
    # 'AnalysisRequestsFolder': '',
    'AnalysisService': 'bika_setup/bika_analysisservices',
    # 'AnalysisServices': '',
    'AnalysisSpec': 'bika_setup/bika_analysisspecs',
    # 'AnalysisSpecs': '',
    # 'Attachment': '',
    'AttachmentType': 'bika_setup/bika_attachmenttypes',
    # 'AttachmentTypes': '',
    # 'Batch': '',
    # 'BatchFolder': '',
    'BatchLabel': 'bika_setup/bika_batchlabels',
    # 'BatchLabels': '',
    # 'BikaSetup': '',
    'Calculation': 'bika_setup/bika_calculations',
    # 'Calculations': '',
    'Client': 'clients',
    # 'ClientFolder': '',
    # 'Collection': '',
    # 'Contact': '',
    'Container': 'bika_setup/bika_containers',
    # 'ContainerType': '',
    # 'ContainerTypes': '',
    # 'Containers': '',
    'Department': 'bika_setup/bika_departments',
    # 'Departments': '',
    # 'Discussion Item': '',
    # 'Document': '',
    # 'DuplicateAnalysis': '',
    # 'Event': '',
    # 'File': '',
    # 'Folder': '',
    'IdentifierType': 'bika_setup/bika_identifiertypes',
    # 'IdentifierTypes': '',
    # 'Image': '',
    'Instrument': 'bika_setup/bika_instruments',
    # 'InstrumentCalibration': '',
    # 'InstrumentCertification': '',
    'InstrumentLocation': 'bika_setup/bika_instrumentlocations',
    # 'InstrumentLocations': '',
    # 'InstrumentMaintenanceTask': '',
    # 'InstrumentScheduledTask': '',
    'InstrumentType': 'bika_setup/bika_instrumenttypes',
    # 'InstrumentTypes': '',
    # 'InstrumentValidation': '',
    # 'Instruments': '',
    # 'Invoice': '',
    # 'InvoiceBatch': '',
    # 'InvoiceFolder': '',
    'LabContact': 'bika_setup/bika_labcontacts',
    # 'LabContacts': '',
    'LabProduct': 'bika_setup/bika_labproducts',
    # 'LabProducts': '',
    # 'Laboratory': '',
    # 'Link': '',
    'Manufacturer': 'bika_setup/bika_manufacturers',
    # 'Manufacturers': '',
    'Method': 'methods',
    # 'Methods': '',
    # 'Multifile': '',
    # 'News Item': '',
    # 'Plone Site': '',
    'Preservation': 'bika_setup/bika_preservations',
    # 'Preservations': '',
    # 'Pricelist': '',
    # 'PricelistFolder': '',
    # 'ReferenceAnalysis': '',
    'ReferenceDefinition': 'bika_setup/bika_referencedefinitions',
    # 'ReferenceDefinitions': '',
    # 'ReferenceSample': '',
    # 'ReferenceSamplesFolder': '',
    # 'RejectAnalysis': '',
    # 'Report': '',
    # 'ReportFolder': '',
    'SRTemplate': 'bika_setup/bika_srtemplates',
    # 'SRTemplates': '',
    # 'Sample': '',
    'SampleCondition': 'bika_setup/bika_sampleconditions',
    # 'SampleConditions': '',
    # 'SampleMatrices': '',
    'SampleMatrix': 'bika_setup/bika_samplematrices',
    # 'SamplePartition': '',
    'SamplePoint': 'bika_setup/bika_samplepoints',
    # 'SamplePoints': '',
    'SampleType': 'bika_setup/bika_sampletypes',
    # 'SampleTypes': '',
    # 'SamplesFolder': '',
    'SamplingDeviation': 'bika_setup/bika_samplingdeviations',
    # 'SamplingDeviations': '',
    'SamplingRound': 'bika_setup/bika_samplingrounds',
    # 'SamplingRounds': '',
    'StorageLocation': 'bika_setup/bika_storagelocations',
    # 'StorageLocations': '',
    'SubGroup': 'bika_setup/bika_subgroups',
    # 'SubGroups': '',
    'Supplier': 'bika_setup/bika_suppliers',
    # 'SupplierContact': '',
    # 'Suppliers': '',
    # 'SupplyOrder': '',
    # 'SupplyOrderFolder': '',
    # 'TempFolder': '',
    # 'Topic': '',
    # 'Worksheet': '',
    # 'WorksheetFolder': '',
    'WorksheetTemplate': 'bika_setup/bika_worksheettemplates',
    # 'WorksheetTemplates': '',
}

ALLOWED_PORTAL_TYPES_TO_CREATE = [
    # 'ARImport',
    # 'ARPriorities',
    # 'ARPriority',
    # 'ARReport',
    'ARTemplate',
    # 'ARTemplates',
    # 'ATBooleanCriterion',
    # 'ATCurrentAuthorCriterion',
    # 'ATDateCriteria',
    # 'ATDateRangeCriterion',
    # 'ATListCriterion',
    # 'ATPathCriterion',
    # 'ATPortalTypeCriterion',
    # 'ATReferenceCriterion',
    # 'ATRelativePathCriterion',
    # 'ATSelectionCriterion',
    # 'ATSimpleIntCriterion',
    # 'ATSimpleStringCriterion',
    # 'ATSortCriterion',
    'Analysis',
    # 'AnalysisCategories',
    'AnalysisCategory',
    'AnalysisProfile',
    # 'AnalysisProfiles',
    'AnalysisRequest',
    # 'AnalysisRequestsFolder',
    'AnalysisService',
    # 'AnalysisServices',
    'AnalysisSpec',
    # 'AnalysisSpecs',
    'Attachment',
    'AttachmentType',
    # 'AttachmentTypes',
    'Batch',
    # 'BatchFolder',
    'BatchLabel',
    # 'BatchLabels',
    # 'BikaSetup',
    'Calculation',
    # 'Calculations',
    'Client',
    # 'ClientFolder',
    # 'Collection',
    'Contact',
    'Container',
    'ContainerType',
    # 'ContainerTypes',
    # 'Containers',
    'Department',
    # 'Departments',
    # 'Discussion Item',
    'Document',
    # 'DuplicateAnalysis',
    # 'Event',
    'File',
    # 'Folder',
    'IdentifierType',
    # 'IdentifierTypes',
    'Image',
    'Instrument',
    'InstrumentCalibration',
    # 'InstrumentCertification',
    'InstrumentLocation',
    # 'InstrumentLocations',
    # 'InstrumentMaintenanceTask',
    # 'InstrumentScheduledTask',
    'InstrumentType',
    # 'InstrumentTypes',
    # 'InstrumentValidation',
    # 'Instruments',
    'Invoice',
    # 'InvoiceBatch',
    # 'InvoiceFolder',
    'LabContact',
    # 'LabContacts',
    'LabProduct',
    # 'LabProducts',
    # 'Laboratory',
    # 'Link',
    'Manufacturer',
    # 'Manufacturers',
    'Method',
    # 'Methods',
    'Multifile',
    # 'News Item',
    # 'Plone Site',
    'Preservation',
    # 'Preservations',
    'Pricelist',
    # 'PricelistFolder',
    # 'ReferenceAnalysis',
    'ReferenceDefinition',
    # 'ReferenceDefinitions',
    'ReferenceSample',
    # 'ReferenceSamplesFolder',
    'RejectAnalysis',
    'Report',
    # 'ReportFolder',
    # 'SRTemplate',
    # 'SRTemplates',
    # 'Sample',
    'SampleCondition',
    # 'SampleConditions',
    # 'SampleMatrices',
    'SampleMatrix',
    # 'SamplePartition',
    'SamplePoint',
    # 'SamplePoints',
    'SampleType',
    # 'SampleTypes',
    # 'SamplesFolder',
    'SamplingDeviation',
    # 'SamplingDeviations',
    # 'SamplingRound',
    # 'SamplingRounds',
    'StorageLocation',
    # 'StorageLocations',
    'SubGroup',
    # 'SubGroups',
    'Supplier',
    'SupplierContact',
    # 'Suppliers',
    'SupplyOrder',
    # 'SupplyOrderFolder',
    # 'TempFolder',
    # 'Topic',
    'Worksheet',
    # 'WorksheetFolder',
    'WorksheetTemplate',
    # 'WorksheetTemplates',
]
